@@ -484,6 +484,7 @@ MpdData * mpd_database_get_directory(MpdObj *mi,const char *path)
 
 MpdData *mpd_database_get_playlist_content(MpdObj *mi,const char *playlist)
 {
+    int i=0;
 	MpdData *data = NULL;
 	mpd_InfoEntity *ent = NULL;
 	if(!mpd_check_connected(mi))
@@ -509,31 +510,24 @@ MpdData *mpd_database_get_playlist_content(MpdObj *mi,const char *playlist)
 	mpd_sendListPlaylistInfoCommand(mi->connection, playlist);
 	while (( ent = mpd_getNextInfoEntity(mi->connection)) != NULL)
 	{
-		data = mpd_new_data_struct_append( data );
-		if(ent->type == MPD_INFO_ENTITY_TYPE_DIRECTORY)
+		if (ent->type == MPD_INFO_ENTITY_TYPE_SONG)
 		{
-			data->type = MPD_DATA_TYPE_DIRECTORY;
-			data->directory = ent->info.directory->path;
-			ent->info.directory->path = NULL;
-		}
-		else if (ent->type == MPD_INFO_ENTITY_TYPE_SONG)
-		{
-			data->type = MPD_DATA_TYPE_SONG;
+            data = mpd_new_data_struct_append( data );
+            data->type = MPD_DATA_TYPE_SONG;
 			data->song = ent->info.song;
+            data->song->pos = i;
 			ent->info.song = NULL;
-		}
-		else if (ent->type == MPD_INFO_ENTITY_TYPE_PLAYLISTFILE)
-		{
-			data->type = MPD_DATA_TYPE_PLAYLIST;
-			data->playlist = ent->info.playlistFile;
-			ent->info.playlistFile= NULL;
-		}
-
+            i++;
+        }
 		mpd_freeInfoEntity(ent);
 	}
 	mpd_finishCommand(mi->connection);
 
-	/* unlock */
+	if(mi->connection->error == MPD_ERROR_ACK && mi->connection->errorCode == MPD_ACK_ERROR_NO_EXIST)
+	{
+		mpd_clearError(mi->connection);
+    }
+    /* unlock */
 	mpd_unlock_conn(mi);
 	if(data == NULL)
 	{
@@ -703,7 +697,7 @@ void mpd_database_search_start(MpdObj *mi, int exact)
  */
 void mpd_database_search_add_constraint(MpdObj *mi, mpd_TagItems field, const char *value)
 {
-	if(mi == NULL || value == NULL )
+	if(mi == NULL )
 	{
 		debug_printf(DEBUG_ERROR,"Failed to parse arguments");
 		return;
@@ -729,7 +723,7 @@ void mpd_database_search_add_constraint(MpdObj *mi, mpd_TagItems field, const ch
 		debug_printf(DEBUG_ERROR, "Failed to lock connection");
 		return ;
 	}
-	mpd_addConstraintSearch(mi->connection, field, value);
+	mpd_addConstraintSearch(mi->connection, field, (value)?value:"");
 	/* unlock, let the error handler handle any possible error.
 	 */
 	mpd_unlock_conn(mi);
